==============
Administration
==============

The device plugin manages the device registration and updates of the peek mobile and desktop systems.

This performs these primary functions :

#.  Pairs the apps/devices to the Peek Client

#.  Assignes deice ids, used for user login and logging

#.  Records the version of software each device is using.

#.  Provides app update functionality.

Nativescript Update Flow Diagram
--------------------------------

.. image:: version_check_workflow.jpeg
